@@ -11,6 +11,7 @@
 #include "interpret.h"
 #include "global.h"
 #include "stralloc.h"
+#include "boolean.h"
 #include "pike_macros.h"
 #include "module_support.h"
 #include "mapping.h"
@@ -48,6 +49,8 @@ typedef struct
   struct object                *fp;
   struct OutBlock*        outStart;
   struct OutBlock*      outCurrent;
+  boolean bold;
+  boolean italic;
 
 } wiki_store;
 
